@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic-More/lib/Perl/Critic/Policy/ErrorHandling/RequireUseOfExceptions.pm $
-#     $Date: 2008-05-04 15:05:26 -0500 (Sun, 04 May 2008) $
+#     $Date: 2008-05-18 19:30:24 -0500 (Sun, 18 May 2008) $
 #   $Author: clonezone $
-# $Revision: 2311 $
+# $Revision: 2372 $
 ##############################################################################
 
 package Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions;
@@ -16,7 +16,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities :classification :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.999_001';
+our $VERSION = '0.999_002';
 
 #-----------------------------------------------------------------------------
 
@@ -53,7 +53,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions
+Perl::Critic::Policy::ErrorHandling::RequireUseOfExceptions - Use exceptions instead of C<die>, C<croak>, or C<confess>.
 
 =head1 AFFILIATION
 
